summaryrefslogtreecommitdiffstats
path: root/khelpcenter/searchengine.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khelpcenter/searchengine.cpp')
-rw-r--r--khelpcenter/searchengine.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/khelpcenter/searchengine.cpp b/khelpcenter/searchengine.cpp
index b779afc8e..12117712d 100644
--- a/khelpcenter/searchengine.cpp
+++ b/khelpcenter/searchengine.cpp
@@ -325,16 +325,16 @@ bool SearchEngine::search( TQString words, TQString method, int matches,
if ( lang.lower() == "c" || lang.lower() == "posix" )
lang = "en";
- // if the string contains '&' replace with a '+' and set search method to and
+ // if the string tqcontains '&' tqreplace with a '+' and set search method to and
if (mWords.find("&") != -1) {
- mWords.replace("&", " ");
+ mWords.tqreplace("&", " ");
method = "and";
}
// replace whitespace with a '+'
mWords = mWords.stripWhiteSpace();
mWords = mWords.simplifyWhiteSpace();
- mWords.replace(TQRegExp("\\s"), "+");
+ mWords.tqreplace(TQRegExp("\\s"), "+");
commonSearchProgram = substituteSearchQuery( commonSearchProgram );
@@ -379,7 +379,7 @@ bool SearchEngine::search( TQString words, TQString method, int matches,
delete mProc;
// modify the search result
- mSearchResult = mSearchResult.replace("http://localhost/", "file:/");
+ mSearchResult = mSearchResult.tqreplace("http://localhost/", "file:/");
mSearchResult = mSearchResult.mid( mSearchResult.find( '<' ) );
mView->beginSearchResult();
@@ -395,11 +395,11 @@ bool SearchEngine::search( TQString words, TQString method, int matches,
TQString SearchEngine::substituteSearchQuery( const TQString &query )
{
TQString result = query;
- result.replace( "%k", mWords );
- result.replace( "%n", TQString::number( mMatches ) );
- result.replace( "%m", mMethod );
- result.replace( "%l", mLang );
- result.replace( "%s", mScope );
+ result.tqreplace( "%k", mWords );
+ result.tqreplace( "%n", TQString::number( mMatches ) );
+ result.tqreplace( "%m", mMethod );
+ result.tqreplace( "%l", mLang );
+ result.tqreplace( "%s", mScope );
return result;
}
@@ -409,15 +409,15 @@ TQString SearchEngine::substituteSearchQuery( const TQString &query,
Operation operation, const TQString &lang )
{
TQString result = query;
- result.replace( "%i", identifier );
- result.replace( "%w", words.join( "+" ) );
- result.replace( "%m", TQString::number( maxResults ) );
+ result.tqreplace( "%i", identifier );
+ result.tqreplace( "%w", words.join( "+" ) );
+ result.tqreplace( "%m", TQString::number( maxResults ) );
TQString o;
if ( operation == Or ) o = "or";
else o = "and";
- result.replace( "%o", o );
- result.replace( "%d", Prefs::indexDirectory() );
- result.replace( "%l", lang );
+ result.tqreplace( "%o", o );
+ result.tqreplace( "%d", Prefs::indexDirectory() );
+ result.tqreplace( "%l", lang );
return result;
}
@@ -325,16 +325,16 @@ bool SearchEngine::search( TQString words, TQString method, int matches,
method = "and";
}
- // replace whitespace with a '+'
+ // tqreplace whitespace with a '+'
mWords = mWords.stripWhiteSpace();
mWords = mWords.simplifyWhiteSpace();